@@ -374,6 +374,44 @@ class GCP:
             f"BigQuery ({job_type}_from_bigquery): Job finished. {General.past_tense(job_type).title()} {-1 * (number_of_rows_after - number_of_rows_before)} rows."
         )
 
+    @staticmethod
+    def latest_file(bucket_name: str) -> str:
+        """
+        Identifies and retrieves the latest file based on the specified
+        bucket name.
+
+        Parameters
+        ----------
+        bucket_name: str, the name of the bucket
+
+        Returns
+        -------
+        A string with the filename of the latest file in the bucket.
+
+        """
+        # Initialise the client
+        storage_client = storage.Client()
+
+        # Make the blobs
+        blobs = storage_client.list_blobs(bucket_name)
+
+        names = []
+        times_created = []
+
+        # Store each blob name and time created in a dict
+        for blob in blobs:
+            name, time_created = blob.name, blob.time_created
+            names.append(name)
+            times_created.append(time_created)
+
+        names_times_dict = dict(zip(times_created, names))
+
+        # Find the latest datetime object
+        latest = max(times_created)
+
+        # Return the filename of the latest object
+        return names_times_dict.get(latest)
+
 
 class CloudSQL:
     """
